@@ -1208,7 +1208,6 @@ double A__align( double **n_dynamicmtx, int penalty_l, int penalty_ex_l, char **
 
 			FreeFloatMtx( doublework );
 			FreeIntMtx( intwork );
-
 		}
 		else
 		{
@@ -1817,6 +1816,9 @@ for( i=0; i<lgth2; i++ )
 		{
 //			fprintf( stderr, "\n\n## CHUUDAN!!! S\n" );
 			*chudanres = 1;
+			free( mseq1 ); // 2021/Sep
+			free( mseq2 ); // 2021/Sep
+			FreeCharMtx( mseq ); // 2021/Sep
 			return( -1.0 );
 		}
 #endif
@@ -1900,6 +1902,9 @@ fprintf( stderr, "\n" );
 			if( chudanpt && *chudanpt != chudanref ) 
 			{
 //				fprintf( stderr, "\n\n## CHUUDAN!!! S\n" );
+				free( mseq1 ); // 2021/Sep
+				free( mseq2 ); // 2021/Sep
+				FreeCharMtx( mseq ); // 2021/Sep
 				*chudanres = 1;
 				return( -1.0 );
 			}
