@@ -14,7 +14,9 @@ static int noalign;
 static int multidist;
 static int maxdist = 2; // scale -> 2bai
 static int allowlongadds;
+static int addtotop;
 static int keeplength;
+static int diffout; // Incomplete. Not used
 static int ndeleted;
 static int mapout;
 static int smoothing;
@@ -55,7 +57,8 @@ typedef struct _thread_arg
 	int  ***topol;
 	double  **len;
 	Addtree *addtree;
-	int **deletelist;
+	GapPos **deletelist;
+	GapPos **difflist;
 #ifdef enablemultithread
 	int *iaddshare;
 	int thread_no;
@@ -793,6 +796,8 @@ void arguments( int argc, char *argv[] )
     int c;
 
 	nthread = 1;
+	codonpos = 0;
+	codonscore = 0;
 	outnumber = 0;
 	scoreout = 0;
 	treein = 0;
@@ -855,7 +860,9 @@ void arguments( int argc, char *argv[] )
 	tuplesize = -1;
 	legacygapcost = 0;
 	allowlongadds = 0;
+	addtotop = 0;
 	keeplength = 0;
+	diffout = 0;
 	mapout = 0;
 	smoothing = 0;
 	distout = 0;
@@ -949,6 +956,12 @@ void arguments( int argc, char *argv[] )
 					fprintf( stderr, "nthread = %d\n", nthread );
 					--argc; 
 					goto nextoption;
+				case 'R':
+					codonpos = 1;
+					break;
+				case 'S':
+					codonscore = 1;
+					break;
 #if 0
 				case 'R':
 					rnaprediction = 'r';
@@ -993,9 +1006,9 @@ void arguments( int argc, char *argv[] )
 					fftNoAnchStop = 1;
 					break;
 #endif
-				case 'S':
-					scoreout = 1;
-					break;
+//				case 'S':
+//					scoreout = 1;
+//					break;
 #if 0
 				case 'e':
 					fftscore = 0;
@@ -1057,6 +1070,9 @@ void arguments( int argc, char *argv[] )
 				case 'U':
 					treein = 1;
 					break;
+				case 'x':
+					addtotop = 1;
+					break;
 				case 'V':
 					allowlongadds = 1;
 					break;
@@ -1092,10 +1108,12 @@ void arguments( int argc, char *argv[] )
 					tbutree = 0;
 					break;
 /* modification end. */
+#if 0
 				case 'z':
 					fftThreshold = myatoi( *++argv );
 					--argc; 
 					goto nextoption;
+#endif
 				case 'w':
 					fftWinSize = myatoi( *++argv );
 					--argc;
@@ -1111,9 +1129,15 @@ void arguments( int argc, char *argv[] )
 				case 'Y':
 					keeplength = 1;
 					break;
+				case 'z':
+					mapout = 2;
+					break;
 				case 'Z':
 					mapout = 1;
 					break;
+				case '%':
+					diffout = 1;
+					break;
 				case ':':
 					nwildcard = 1;
 					break;
@@ -1398,6 +1422,11 @@ static double treebase( int nseq, int *nlen, char **aseq, int nadd, char *mergeo
 
 		if( constraint == 2 )
 		{
+			if( codonpos )
+			{
+				reporterr( "\n\nThe --codonpos option is supported only for --6merpair --addfragments at this point. Add the --6merpair flag, for now.\n\n\n" );
+				exit( 1 );
+			}
 			if( alg == 'M' )
 			{
 				fprintf( stderr, "\n\nMemory saving mode is not supported.\n\n" );
@@ -1598,7 +1627,8 @@ static void	*addsinglethread( void *arg )
 		int ***topol = targ->topol;
 		double **len = targ->len;
 		Addtree *addtree = targ->addtree;
-		int **deletelist = targ->deletelist;
+		GapPos **deletelist = targ->deletelist;
+		GapPos **difflist = targ->difflist;
 		double pscore;
 		int *alnleninnode = NULL;
 		char *targetseq;
@@ -1807,7 +1837,11 @@ static void	*addsinglethread( void *arg )
 //			{
 //			}
 //			fixed_musclesupg_double_realloc_nobk_halfmtx( njobc, iscorec, topolc, lenc, depc, 0, 1 );
-			neighbor = addonetip( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name, alnleninnode, nogaplenjusttodecideaddhereornot, noalign );
+
+			if( addtotop )
+				neighbor = addonetip2top( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name, alnleninnode, nogaplenjusttodecideaddhereornot, noalign );
+			else
+				neighbor = addonetip( njobc, topolc, lenc, iscorec, topol, len, dep, treeout, addtree, iadd, name, alnleninnode, nogaplenjusttodecideaddhereornot, noalign );
 
 
 			FreeFloatHalfMtx( iscorec, njobc );
@@ -1944,8 +1978,16 @@ static void	*addsinglethread( void *arg )
 	
 //			strcpy( seq[norg+iadd], bseq[norg] );
 
-	
-			if( keeplength )
+
+			if( diffout )
+			{
+				reporterr( "Not yet written\n" );
+				exit( 1 );
+//				deletenewinsertions_difflist( norg, 1, bseq, bseq+norg, difflist+iadd );
+//				strcpy( targetseq, bseq[norg] );
+//				i = norg; // no new gap!!
+			}
+			else if( keeplength )
 			{
 //				reporterr( "deletelist = %p\n", deletelist );
 //				reporterr( "deletelist+iadd = %p\n", deletelist+iadd );
@@ -2942,7 +2984,8 @@ int main( int argc, char *argv[] )
 	double **len;
 	double **iscoreo, **nscore;
 	FILE *fp;
-	int **deletelist = NULL;
+	GapPos **deletelist = NULL;
+	GapPos **difflist = NULL;
 	char **addbk = NULL;
 	char *originalgaps = NULL;
 	Addtree *addtree;
@@ -3269,32 +3312,51 @@ int main( int argc, char *argv[] )
 	singlerna = NULL;
 
 
-	if( keeplength )
+	if( diffout )
 	{
 		lenfull = strlen( seq[0] );
-		originalgaps = (char *)calloc( lenfull+1, sizeof( char) );
+		originalgaps = (char *)calloc( lenfull+1, sizeof( char ) );
+		recordoriginalgaps( originalgaps, norg, seq );
+
+		difflist = (GapPos **)calloc( nadd+1, sizeof( GapPos * ) );
+		for( i=0; i<nadd; i++ )
+		{
+			difflist[i] = calloc( 1, sizeof( GapPos ) );
+			difflist[i][0].pos = -1;
+			difflist[i][0].len = 0;
+		}
+		difflist[nadd] = NULL;
+		deletelist = NULL;
+	}
+
+	else if( keeplength )
+	{
+		lenfull = strlen( seq[0] );
+		originalgaps = (char *)calloc( lenfull+1, sizeof( char ) );
 		recordoriginalgaps( originalgaps, norg, seq );
 
 
-		deletelist = (int **)calloc( nadd+1, sizeof( int * ) );
+		deletelist = (GapPos **)calloc( nadd+1, sizeof( GapPos * ) );
 		for( i=0; i<nadd; i++ )
 		{
-			deletelist[i] = calloc( 1, sizeof( int ) );
-			deletelist[i][0] = -1;
+			deletelist[i] = calloc( 1, sizeof( GapPos ) );
+			deletelist[i][0].pos = -1;
+			deletelist[i][0].len = 0;
 		}
 		deletelist[nadd] = NULL;
-
+		difflist = NULL;
 	}
 	else
 	{
 		originalgaps = NULL;
 		deletelist = NULL;
+		difflist = NULL;
 	}
 
 	commongappick( norg, seq );
 	lenfull = strlen( seq[0] );
 
-	if( ratioambiguouscolumn_simple( seq, norg, lenfull ) > 0.03 )
+	if( 0 && ratioambiguouscolumn_simple( seq, norg, lenfull ) > 0.03 )
 	{
 		fprintf( stderr, "################################################################################\n" );
 		fprintf( stderr, "# \n" );
@@ -3418,6 +3480,7 @@ int main( int argc, char *argv[] )
 			targ[i].len = len;
 			targ[i].addtree = addtree;
 			targ[i].deletelist = deletelist;
+			targ[i].difflist = difflist;
 			targ[i].mutex_counter = &mutex_counter;
 			pthread_create( handle+i, NULL, addsinglethread, (void *)(targ+i) );
 		}
@@ -3454,6 +3517,7 @@ int main( int argc, char *argv[] )
 		targ[0].len = len;
 		targ[0].addtree = addtree;
 		targ[0].deletelist = deletelist;
+		targ[0].difflist = difflist;
 		addsinglethread( targ );
 		free( targ );
 	}
@@ -3721,15 +3785,18 @@ int main( int argc, char *argv[] )
 		for( i=0; i<nadd; i++ )
 		{
 			if( deletelist[i] )
-				for( j=0; deletelist[i][j]!=-1; j++ )
-					fprintf( dlf, "%d %d\n", njob-nadd+i, deletelist[i][j] ); // 0origin
+				for( j=0; deletelist[i][j].pos!=-1; j++ )
+					fprintf( dlf, "%d %d %d\n", njob-nadd+i, deletelist[i][j].pos, deletelist[i][j].len ); // 0origin
 		}
 		fclose( dlf );
 
 		if( mapout )
 		{
 			dlf = fopen( "_deletemap", "w" );
-			reconstructdeletemap( nadd, addbk, deletelist, seq+njob-nadd, dlf, name+njob-nadd );
+			if( mapout == 1 )
+				reconstructdeletemap( nadd, addbk, deletelist, seq+njob-nadd, dlf, name+njob-nadd );
+			else
+				reconstructdeletemap_compact( nadd, addbk, deletelist, seq+njob-nadd, dlf, name+njob-nadd );
 			fclose( dlf );
 		}
 	}
@@ -3752,7 +3819,18 @@ int main( int argc, char *argv[] )
 	FreeCharMtx( tmpseq );
 	freeconstants();
 	if( addbk ) FreeCharMtx( addbk ); addbk = NULL;
-	if( deletelist ) FreeIntMtx( deletelist ); deletelist = NULL;
+	if( deletelist ) 
+	{
+		for( i=0; deletelist[i] != NULL; i++ ) free( deletelist[i] );
+		free( deletelist );
+		deletelist = NULL;
+	}
+	if( difflist ) 
+	{
+		for( i=0; difflist[i] != NULL; i++ ) free( difflist[i] );
+		free( difflist );
+		difflist = NULL;
+	}
 	if( originalgaps ) free( originalgaps ); originalgaps = NULL;
 
 	writeData_pointer( prep_g, njob, name, nlen, seq );
