@@ -131,6 +131,8 @@ double sueff_global = SUEFF;
 double lenfaca, lenfacb, lenfacc, lenfacd;
 int maxl, tsize;
 
+char codonpos = 0;
+char codonscore = 0;
 
 
 void initglobalvariables()
