@@ -256,9 +256,9 @@ int alignableReagion( int    clus1, int    clus2,
 		j = clus1;
 		while( j-- ) prf1[amino_n[(*seq1pt++)[i]]] += *eff1pt++;
 #else
-		for( j=0; j<clus1; j++ ) prf1[amino_n[(int)seq1[j][i]]] += eff1[j];
+		for( j=0; j<clus1; j++ ) prf1[amino_n[(unsigned char)seq1[j][i]]] += eff1[j];
 #endif
-		for( j=0; j<clus2; j++ ) prf2[amino_n[(int)seq2[j][i]]] += eff2[j];
+		for( j=0; j<clus2; j++ ) prf2[amino_n[(unsigned char)seq2[j][i]]] += eff2[j];
 
 		/* make hats */
 		pre1 = pre2 = nalphabets;
