@@ -36,7 +36,7 @@
 
 
 
-#define VERSION "7.490"
+#define VERSION "7.505"
 #define SHOWVERSION reporterr( "%s (%s) Version " VERSION "\nalg=%c, model=%s, amax=%3.1f\n%d thread(s)\n\n", progName( argv[0] ), (dorp=='d')?"nuc":((nblosum==-2)?"text":"aa"), alg, modelname, specificityconsideration, nthread )
 
 #define FFT_THRESHOLD  80
@@ -331,6 +331,13 @@ typedef struct _extanch
 	int score;
 } ExtAnch;
 
+typedef struct _gappos
+{
+	int pos;
+	int len;
+} GapPos;
+
+
 #include "fft.h"
 #include "dp.h"
 #include "functions.h"
@@ -376,6 +383,9 @@ extern double sueff_global;
 extern double lenfaca, lenfacb, lenfacc, lenfacd;
 extern int maxl, tsize;
 
+extern char codonpos;
+extern char codonscore;
+
 
 /* for --large  */
 extern int compacttree;
