@@ -1150,7 +1150,7 @@ static void pairalign( char **name, int nlen[M], char **seq, char **aseq, char *
 			fprintf( stderr, "score = %10.2f (%d,%d)\n", pscore, i, j );
 #endif
 
-			putlocalhom_str( mseq1[0], mseq2[0], equiv, scale, localhomtable[i]+j, off1, off2, (int)pscore, strlen( mseq1[0] ) );
+			putlocalhom_str( mseq1[0], mseq2[0], equiv, scale, localhomtable[i]+j, off1, off2, (int)pscore, strlen( mseq1[0] ), 'k' );
 #if 1
 
 			if( alreadyoutput[i] == 0 )
