@@ -3133,7 +3133,7 @@ int pairlocalalign( int ngui, int lgui, char **namegui, char **seqgui, double **
 		if( njob > M )
 		{
 			fprintf( stderr, "The number of sequences must be < %d\n", M );
-			fprintf( stderr, "Please try the splittbfast program for such large data.\n" );
+			fprintf( stderr, "Please try --6merpair --addfragments for such large data.\n" );
 			exit( 1 );
 		}
 	}
