@@ -269,11 +269,12 @@ static void freelocalarrays(
 	int **whichmtx
 )
 {
-//	fprintf( stderr, "Skipping freelocalarrays\n" );
-//	return;
+//	fprintf( stderr, "freelocalarrays\n" );
 	int i;
 	if( commonIP ) FreeIntMtx( commonIP );
 	commonIP = NULL;
+	commonAlloc1 = 0;
+	commonAlloc2 = 0;
 	Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
 	Falign_localhom( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL,NULL, 0, NULL );
 	D__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
@@ -1330,7 +1331,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	Writeoptions( trap_g );
 	fflush( trap_g );
 
-	if( effarr == NULL ) /* locnjob == njob ni kagiru */
+	if( 1 || effarr == NULL ) /* locnjob == njob ni kagiru */
 	{
 		indication1 = AllocateCharVec( 150 );
 		indication2 = AllocateCharVec( 150 );
@@ -2384,8 +2385,38 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	value = 2;
 
 	end:
-	if( grouprna1 ) free( grouprna1 );
-	if( grouprna2 ) free( grouprna2 );
+//	if( grouprna1 ) free( grouprna1 );
+//	if( grouprna2 ) free( grouprna2 );
+
+#if 1
+				freelocalarrays
+				( 
+					NULL,
+					grouprna1, grouprna2,
+					rnapairboth,
+					indication1, indication2,
+					distarr,
+					effarr, effarrforlocalhom, effarr1, effarr2,
+					mseq1, mseq2,
+					NULL,
+					gapmap1, gapmap2,
+					effarr1_kozo, effarr2_kozo, effarr_kozo,
+					memlist, pairbuf,
+					localhomshrink,
+					swaplist,
+					smalldistmtx,
+					scoringmatrices,
+					eff1s, eff2s,
+					whichmtx
+				);
+	if( branchnode ) free( branchnode );
+	if( stopol) free( stopol );
+	if( mtx ) FreeDoubleMtx( mtx );
+	if( node ) FreeIntMtx( node );
+	if( branchWeight ) FreeDoubleMtx( branchWeight );
+	if( history) FreeFloatCub( history );
+	treeCnv( NULL, 0, 0, NULL, NULL ); // 2021/Sep
+#endif
 //	freelocalarrays
 //	( 
 //		NULL,
@@ -2407,5 +2438,6 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 //	);
 //	free( branchnode );
 //	free( stopol );
+//
 	return( value );
 }                  	   /* int Tree... */
